==> spip_3.2.11.orig.tar.xz: plugins-dist/mots/lang/mots_oc_ni.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=oc_ni
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Grop important:</b> es foart aconselhat de seleccionar un mòt clau dins aqueu grop.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'Lu administrators dau sit',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'lu redactors',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'lu visitaires dau sit public quora poaston un messatge dins un fòro.',

	// I
	'icone_creation_groupe_mots' => 'Crear un novèu grop de mòts',
	'icone_creation_mots_cles' => 'Crear un novèu mòt clau ',
	'icone_modif_groupe_mots' => 'Modificar aqueu grop de mòts',
	'icone_mots_cles' => 'Mòts claus',
	'icone_supprimer_groupe_mots' => 'Suprimir aqueu document',
	'icone_voir_tous_mots_cles' => 'Veire toi lu mòts claus',
	'info_articles_lies_mot' => 'Lu articles ligats à-n-aqueu mòt clau',
	'info_changer_nom_groupe' => 'Cambiar lo nom d’aqueu grop:',
	'info_creation_mots_cles' => 'Creatz e configuratz aquí lu mòts claus dau sit',
	'info_dans_groupe' => 'Dins lo grop:',
	'info_delet_mots_cles' => 'Avètz demandat de suprimir lo mòt clau
<b>@titre_mot@</b> (@type_mot@). Aqueu mòt clau es ligat à <b>@texte_lie@</b>. Devètz confirmar aquela decision :', # MODIF
	'info_groupe_important' => 'Grop important',
	'info_modifier_mot' => 'Modificar lo mot clau :',
	'info_mots_cles' => 'Lu mòts claus',
	'info_mots_cles_association' => 'Lu mòts claus d’aqueu grop poadon èstre associats :',
	'info_oui_suppression_mot_cle' => 'Voali suprimir aqueu mòt clau definitivament.',
	'info_question_mots_cles' => 'Desiratz d’utilisar lu mòts claus sus lo voastre sit?',
	'info_qui_attribue_mot_cle' => 'Lu mòts d’aqueu grop poadon èstre atribuits de :',
	'info_retirer_mot' => 'Traire aqueu mòt',
	'info_retirer_mots' => 'Traire toi lu mòts',
	'info_rubriques_liees_mot' => 'Li rubricas ligadi à-n-aqueu mòt clau',
	'info_selection_un_seul_mot_cle' => 'Si pòu seleccionar qu’<b>un mòt clau</b> à l’encòup dins aqueu grop.', # MODIF
	'info_supprimer_mot' => 'suprimir aqueu mòt',
	'info_titre_mot_cle' => 'Nom ò titre dau mòt clau',
	'info_un_mot' => 'Un sol mòt à l’encòup',
	'item_ajout_mots_cles' => 'Autorisar l’ajust de mòts claus ai fòros',
	'item_non_ajout_mots_cles' => 'Proïbir l’utilisacion dei mòts claus dins lu fòros',
	'item_non_utiliser_config_groupe_mots_cles' => 'Utilisar pas la configuracion avançada dei grops de mòts claus',
	'item_non_utiliser_mots_cles' => 'Utilisar pas lu mòts claus',
	'item_utiliser_config_groupe_mots_cles' => 'Utilisar la configuracion avançada dei grops de mòts claus',
	'item_utiliser_mots_cles' => 'Utilisar lu mòts claus',

	// L
	'logo_mot_cle' => 'LÒGO DAU MÒT CLAU',

	// T
	'texte_config_groupe_mots_cles' => 'Desiratz d’activar la configuracion avançada dei mòts claus,
 en indicant per exemple que si pòu seleccionar un mòt unic
 per grop, qu’un grop es important... ?', # MODIF
	'texte_mots_cles' => 'Lu mòts claus permeton crear de ligams tematics entre lu voastres articles
  quauque que sigue la sieua plaça dins li rubricas. Aquò vos permete
  d’enriquir la navigacion dau voastre site, e mai d’utilisar aqueli proprietats 
  per personalisar la presentacion dei articles dins li esqueletas. ',
	'texte_mots_cles_dans_forum' => 'Desiratz de permetre l’utilisacion dei mòts claus seleccionables dai visitaires dins lu fòros dau sit public ? (Atencion: es pron complèxe d’utilisar aquela opcion correctament.)',
	'texte_nouveau_mot' => 'Novèu mòt',
	'titre_config_groupe_mots_cles' => 'Configuracion dei grops de mòts claus',
	'titre_gauche_mots_edit' => 'MÒT NÚMERO :',
	'titre_mots_cles_dans_forum' => 'Mòts claus dins lu fòros dau sit public',
	'titre_mots_tous' => 'Lu mòts claus',
	'titre_nouveau_groupe' => 'Novèu grop',
	'titre_page_mots_tous' => 'Mòts claus'
);

==> spip_4.4.3+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_oc_ni.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=oc_ni
// ** ne pas modifier le fichier **

return [

	// A
	'avis_conseil_selection_mot_cle' => '<b>Grop important:</b> es foart aconselhat de seleccionar un mòt clau dins aqueu grop.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'Lu administrators dau sit',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'lu redactors',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'lu visitaires dau sit public quora poaston un messatge dins un fòro.',

	// I
	'icone_creation_groupe_mots' => 'Crear un novèu grop de mòts',
	'icone_creation_mots_cles' => 'Crear un novèu mòt clau ',
	'icone_modif_groupe_mots' => 'Modificar aqueu grop de mòts',
	'icone_mots_cles' => 'Mòts claus',
	'icone_supprimer_groupe_mots' => 'Suprimir aqueu document',
	'icone_voir_tous_mots_cles' => 'Veire toi lu mòts claus',
	'info_articles_lies_mot' => 'Lu articles ligats à-n-aqueu mòt clau',
	'info_changer_nom_groupe' => 'Cambiar lo nom d’aqueu grop:',
	'info_creation_mots_cles' => 'Creatz e configuratz aquí lu mòts claus dau sit',
	'info_dans_groupe' => 'Dins lo grop:',
	'info_delet_mots_cles' => 'Avètz demandat de suprimir lo mòt clau
<b>@titre_mot@</b> (@type_mot@). Aqueu mòt clau es ligat à <b>@texte_lie@</b>. Devètz confirmar aquela decision :', # MODIF
	'info_groupe_important' => 'Grop important',
	'info_modifier_mot' => 'Modificar lo mot clau :',
	'info_mots_cles' => 'Lu mòts claus',
	'info_mots_cles_association' => 'Lu mòts claus d’aqueu grop poadon èstre associats :',
	'info_oui_suppression_mot_cle' => 'Voali suprimir aqueu mòt clau definitivament.',
	'info_question_mots_cles' => 'Desiratz d’utilisar lu mòts claus sus lo voastre sit?',
	'info_qui_attribue_mot_cle' => 'Lu mòts d’aqueu grop poadon èstre atribuits de :',
	'info_retirer_mot' => 'Traire aqueu mòt',
	'info_retirer_mots' => 'Traire toi lu mòts',
	'info_rubriques_liees_mot' => 'Li rubricas ligadi à-n-aqueu mòt clau',
	'info_selection_un_seul_mot_cle' => 'Si pòu seleccionar qu’<b>un mòt clau</b> à l’encòup dins aqueu grop.', # MODIF
	'info_supprimer_mot' => 'suprimir aqueu mòt',
	'info_titre_mot_cle' => 'Nom ò titre dau mòt clau',
	'info_un_mot' => 'Un sol mòt à l’encòup',
	'item_ajout_mots_cles' => 'Autorisar l’ajust de mòts claus ai fòros',
	'item_non_ajout_mots_cles' => 'Proïbir l’utilisacion dei mòts claus dins lu fòros',
	'item_non_utiliser_config_groupe_mots_cles' => 'Utilisar pas la configuracion avançada dei grops de mòts claus',
	'item_non_utiliser_mots_cles' => 'Utilisar pas lu mòts claus',
	'item_utiliser_config_groupe_mots_cles' => 'Utilisar la configuracion avançada dei grops de mòts claus',
	'item_utiliser_mots_cles' => 'Utilisar lu mòts claus',

	// L
	'logo_mot_cle' => 'LÒGO DAU MÒT CLAU',

	// T
	'texte_config_groupe_mots_cles' => 'Desiratz d’activar la configuracion avançada dei mòts claus,
 en indicant per exemple que si pòu seleccionar un mòt unic
 per grop, qu’un grop es important... ?', # MODIF
	'texte_mots_cles' => 'Lu mòts claus permeton crear de ligams tematics entre lu voastres articles
  quauque que sigue la sieua plaça dins li rubricas. Aquò vos permete
  d’enriquir la navigacion dau voastre site, e mai d’utilisar aqueli proprietats 
  per personalisar la presentacion dei articles dins li esqueletas. ',
	'texte_mots_cles_dans_forum' => 'Desiratz de permetre l’utilisacion dei mòts claus seleccionables dai visitaires dins lu fòros dau sit public ? (Atencion: es pron complèxe d’utilisar aquela opcion correctament.)',
	'texte_nouveau_mot' => 'Novèu mòt',
	'titre_config_groupe_mots_cles' => 'Configuracion dei grops de mòts claus',
	'titre_gauche_mots_edit' => 'MÒT NÚMERO :',
	'titre_mots_cles_dans_forum' => 'Mòts claus dins lu fòros dau sit public',
	'titre_mots_tous' => 'Lu mòts claus',
	'titre_nouveau_groupe' => 'Novèu grop',
	'titre_page_mots_tous' => 'Mòts claus',
];
